.. _api_references:

==============
API references
==============


.. toctree::
    :hidden:

    ../modules/mappings.rst
    ../modules/solvers.rst

.. include:: ../modules/mappings.rst
.. include:: ../modules/solvers.rst
